@@ -53,10 +53,15 @@ class Config(object):
         self.company_vpn_region = None
         self.up = False
         self.down = False
+        self.get_args()
 
-        if create_config and not os.path.isfile(self.LAZYVPN_CONFIG):
-            self.ui.notify('No lazy-vpn configuration file found, starting first-time configuration...')
-            self.update_config_file()
+        if self.action_configure or (create_config and not os.path.isfile(self.LAZYVPN_CONFIG)):
+            if self.action_configure:
+                self.update_config_file()
+                raise errors.LazyVpnExitSuccess()
+            else:
+                self.ui.notify('No lazy-vpn configuration file found, starting first-time configuration...')
+                self.update_config_file()
 
     def get_args(self):
         """Get the CLI args"""
@@ -70,8 +75,6 @@ class Config(object):
         args = parser.parse_args(self.ui.args)
         self.action_configure = args.action_configure
         self.conf_profile = args.profile or 'DEFAULT'
-        if not self.action_configure and args.up == args.down:
-            raise ValueError("Can't have both be UP and DOWN the same value")
         return args
 
     def _handle_config(self, config, profile_config, include_inherits=True):
@@ -135,10 +138,11 @@ class Config(object):
         # Prompt user for config details and store in config_dict
         config_dict = defaults
         config_dict['okta_username'] = self._get_okta_username(defaults['okta_username'])
-        self._set_okta_password(config_dict['okta_username'])
+        self.get_okta_password(config_dict['okta_username'])
         config_dict['company_vpn_region'] = self._get_company_vpn_region(DEFAULT_VPN_REGION)
         self.write_config_file(config_dict)
 
+
     def write_config_file(self, config_dict):
         config = configparser.ConfigParser()
         config.read(self.LAZYVPN_CONFIG)
@@ -161,6 +165,7 @@ class Config(object):
                 self.ui.info("Password for {} saved in keyring.".format(username))
             except RuntimeError as err:
                 self.ui.warning("Failed to save password in keyring: " + str(err))
+        return password
 
     def _get_user_input_with_default_value(self, message, default=None, hidden=False):
         """formats message to include default and then prompts user for input
@@ -228,12 +233,13 @@ class Config(object):
             "Okta User Name", default_entry)
         return okta_username
 
-    def _set_okta_password(self, okta_username):
+    def get_okta_password(self, okta_username):
         """Get and validate okta password. [Optional]"""
         ui.default.message(
-            "Set Okta Password that will be stored under system keychain")
-        self._get_user_input_for_password(
+            "Set Okta Password that will be used to connect to vpn")
+        okta_password = self._get_user_input_for_password(
             okta_username, "Okta Pass Word")
+        return okta_password
 
     def _get_company_vpn_region(self, default_list : List[str]):
         """ Get Okta AWS App name """
