@@ -14,28 +14,21 @@ class LazyVpn(object):
     ]
 
     def _run(self):
-        # Generate one-time login code using the secret key
-        self.handle_action_configure()
         username = self.conf_arg_dict['okta_username']
         password = keyring.get_password(LAZY_VPN_KEYCHAIN_SERVICE_NAME, username)
+        if not password:
+            password = self.config.get_okta_password(username)
         company_vpn_region = self.conf_arg_dict['company_vpn_region']
+        if self.conf_arg_dict['down']:
+            call(['bash', '-c', '/opt/cisco/anyconnect/bin/vpn -s disconnect'])
         if self.conf_arg_dict['up']:
             call(['bash', '-c', f'printf "{username}\n{password}\n2"  | /opt/cisco/anyconnect/bin/vpn -s connect "{company_vpn_region}"'])
-        elif self.conf_arg_dict['down']:
-            call(['bash', '-c', '/opt/cisco/anyconnect/bin/vpn -s disconnect'])
 
     def __init__(self, ui=ui.cli):
         self.ui = ui
         self.FILE_ROOT = self.ui.HOME
         self._cache = {}
 
-    def handle_action_configure(self):
-        # Create/Update config when configure arg set
-        if not self.config.action_configure:
-            return
-        self.config.update_config_file()
-        raise errors.LazyVpnExitSuccess()
-
     def run(self):
         try:
             self._run()
